@@ -2,8 +2,8 @@ package Glib::Install::Files;
 
 $self = {
           'deps' => [],
-          'inc' => ' -I. -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/lib/libffi-3.2.1/include  -pthread -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include ',
-          'libs' => '-lgobject-2.0 -lglib-2.0  -pthread -lgthread-2.0 -lglib-2.0 ',
+          'inc' => ' -I. -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include  -pthread -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include ',
+          'libs' => '-lgobject-2.0 -lglib-2.0  -lgthread-2.0 -pthread -lglib-2.0 ',
           'typemaps' => [
                           'typemap'
                         ]
@@ -26,11 +26,6 @@ $inc = $self->{inc};
 
 	sub Inline {
 		my ($class, $lang) = @_;
-		if ($lang ne 'C') {
-			warn "Warning: Inline hints not available for $lang language
-";
-			return;
-		}
 		+{ map { (uc($_) => $self->{$_}) } qw(inc libs typemaps) };
 	}
 
